/*
 * IBM Confidential
 *
 * OCO Source Materials
 *
 * 0000-000
 *
 * (C) Copyright IBM Corp. 2002.
 *
 * The source code for this program is not published or other-
 * wise divested of its trade secrets, irrespective of what has
 * been deposited with the U. S. Copyright Office.
 */


package com.ibm.osg.sample.simpledriverlocator;
import org.osgi.framework.*;
import org.osgi.util.tracker.*;
import javax.xml.parsers.*;
import java.security.*;
/**
 * The SimpleDriverLocatorActivator is the bundle activator for the
 * SimpleDriverLocator  It is responsible for registering the 
 * SimpleDriverLocator as a DriverLocator service.  It will register
 * the service only when an xml parser is available.  
 *
 */

public class SimpleDriverLocatorActivator implements BundleActivator, ServiceTrackerCustomizer {

	final protected static String driverLocatorClazz = "org.osgi.service.device.DriverLocator";
	final protected static String saxFactoryClazz = "javax.xml.parsers.SAXParserFactory";
	
	private ServiceRegistration registration;
	private ServiceTracker parserTracker;
	private BundleContext context;
	private boolean driverLocatorRegistered = false;
	
	
	/**
	 * In the start method, we create and open a ServiceTracker which will
	 * track registered XML parsers  
	 * @see BundleActivator#start(BundleContext)
	 *
	 */
	public void start(BundleContext context) throws Exception {
		this.context = context;
		parserTracker = new ServiceTracker(context,saxFactoryClazz,this);
		parserTracker.open();
	}

	/**
	 * @see BundleActivator#stop(BundleContext)
	 */
	public void stop(BundleContext context) throws Exception {
		parserTracker.close();
	}
 
  /**
    *  When an XML parser service becomes available, initialize the driver 
    *  locator and register it.   
    */
	public Object addingService(ServiceReference ref)
	{
		SAXParserFactory parserFactory = (SAXParserFactory)context.getService(ref);;
		if(!driverLocatorRegistered)
		{
			final SimpleDriverLocator driverLocator = new SimpleDriverLocator(parserFactory);
                        
                        registration = (ServiceRegistration)AccessController.doPrivileged(new PrivilegedAction() {
                                public java.lang.Object run() {
                                    return context.registerService(driverLocatorClazz,driverLocator,null);
                                }
                                });
                        
                        
                        
                        
			driverLocatorRegistered = true;
		}
		return (parserFactory);
		
	}
	
	public void modifiedService(ServiceReference ref,Object object)
	{
		
	}
	
   /**
    * When the XML parser service is unregistered, we need to unregister 
    * SimpleDriverLocator (It needs an XML parser to parse it's data).
    * 
    */	
	
	public void removedService(ServiceReference ref, Object object)
	{
		registration.unregister();
		driverLocatorRegistered = false;
	}	
}

