/* .COPYRIGHT:                                                                */
/*    Licensed Material - Program-Property of IBM                             */
/*    (C) Copyright IBM Corp. 2002 - All Rights Reserved                      */
/*                                                                            */
/* .DISCLAIMER:                                                               */
/*   The following [enclosed] code is sample code created by IBM              */
/*   Corporation.  This sample code is provided to you solely for use in      */
/*   connection with your internal evaluation of the Service Management       */
/*   Framework(TM) Toolkit (Program) during the term of Early Release license */
/*   for the Program, and for no other purpose.  The code is provided 'AS IS',*/
/*   without warranty of any kind.  IBM shall not be liable for any damages   */
/*   arising out of your use of the sample code, even if they have been       */
/*   advised of the possibility of such damages.                              */
package com.ibm.pvc.example.calendar;

import java.net.URLEncoder;
import java.util.ArrayList;
import java.util.Calendar;

import javax.servlet.http.HttpServletRequest;

import com.ibm.pvc.example.calendar.model.DayInfo;
import com.ibm.pvc.example.calendar.model.Event;
import com.ibm.pvc.example.calendar.model.EventDAO;

/**
 * This is the CalendarServletHelper class.
 * 
 * This helper class provides methods that are useful across a variety of classes
 * within the Calendar application.
 */
public class CalendarServletHelper {
	private final static EventDAO eventDAO = new EventDAO();


	/**
	 * @see java.lang.Object#Object()
	 */
	public CalendarServletHelper() {
		super();
	}

	/**
	 * Method buildServletActionUrl.
	 * @param action
	 * @return String
	 */
	public final static String buildServletActionUrl(String action) {
		return CalendarServlet.SERVLET_URI
			+ "?"
			+ CalendarConstants.PARM_ACTION
			+ "="
			+ action;
	}

	/**
	 * Method buildServletUrlParmAddition.
	 * @param parmName
	 * @param intValue
	 * @return String
	 */
	public final static String buildServletUrlParmAddition(
		String parmName,
		int intValue) {
		return "&" + parmName + "=" + intValue;
	}
	/**
	 * Method buildServletUrlParmAddition.
	 * @param parmName
	 * @param longValue
	 * @return String
	 */
	public final static String buildServletUrlParmAddition(
		String parmName,
		long longValue) {
		return "&" + parmName + "=" + longValue;
	}
	/**
	 * Method buildServletUrlParmAddition.
	 * @param parmName
	 * @param value
	 * @return String
	 */
	public final static String buildServletUrlParmAddition(
		String parmName,
		Integer value) {
		return "&" + parmName + "=" + value;
	}
	/**
	 * Method buildServletUrlParmAddition.
	 * @param parmName
	 * @param parmValue
	 * @return String
	 */
	public final static String buildServletUrlParmAddition(
		String parmName,
		String parmValue) {
		return "&" + parmName + "=" + URLEncoder.encode(parmValue);
	}
	/**
	 * Method buildServletUrlParmAddition.
	 * @param parmName
	 * @param dateValue
	 * @return String
	 */
	public final static String buildServletUrlParmAddition(
		String parmName,
		java.util.Calendar dateValue) {
		return "&" + parmName + "=" + dateValue.getTime().getTime();
	}

	/**
	 * Method createDayInfos.
	 * @param events
	 * @param rangeBegin
	 * @param rangeEnd
	 * @return DayInfo[]
	 */
	public static final DayInfo[] createDayInfos(
		Event[] events,
		Calendar rangeBegin,
		Calendar rangeEnd) {
		ArrayList dayInfoList = new ArrayList();

		Calendar beginDay =
			CalendarServletHelper.getStartOfDayCalendarInstance(rangeBegin),
			endDay =
				CalendarServletHelper.getEndOfDayCalendarInstance(rangeEnd);

		Calendar tempCal = (Calendar) beginDay.clone();

		while (tempCal.before(endDay)) {
			dayInfoList.add(new DayInfo(tempCal));
			tempCal.add(Calendar.HOUR, 24);
		}

		DayInfo[] dayInfos = new DayInfo[dayInfoList.size()];

		dayInfos = (DayInfo[]) dayInfoList.toArray(dayInfos);

		for (int i = 0; i < events.length; i++) {
			Event event = events[i];
			Calendar evtStart = event.getEvtStart();
			Calendar evtEnd = event.getEvtEnd();
			if (evtEnd == null) {
				getDayInfoForDay(dayInfos, evtStart).addEvent(event);
			}
			else if (
				evtStart.get(Calendar.DAY_OF_YEAR)
					== evtEnd.get(Calendar.DAY_OF_YEAR)) {
				getDayInfoForDay(dayInfos, evtStart).addEvent(event);
			}
			else {
				Calendar lowerRange =
					(evtStart.before(rangeBegin) ? rangeBegin : evtStart);
				Calendar upperRange =
					(evtEnd.after(rangeEnd) ? rangeEnd : evtEnd);
				tempCal = (Calendar) lowerRange.clone();
				while (tempCal.before(upperRange)) {
					getDayInfoForDay(dayInfos, tempCal).addEvent(event);
					tempCal.add(Calendar.HOUR_OF_DAY, 24);
				}
			}
		}
		return dayInfos;
	}

	/**
	 * Method getAppCalendarInstance.
	 * @return Calendar
	 */
	public static final java.util.Calendar getAppCalendarInstance() {
		java.util.Calendar appCalendar = java.util.Calendar.getInstance();
		// In future versions of the code, user tailoring of the calendar could be added.
		// For example, allowing the user to select what day to being the week on.
		// Setting those tailored values would be done at this point in the code. 
		return appCalendar;
	}

	/**
	 * Method getAppCalendarInstance.
	 * @param date
	 * @return Calendar
	 */
	public static final java.util.Calendar getAppCalendarInstance(
		java.util.Date date) {
		java.util.Calendar appCalendar =
			CalendarServletHelper.getAppCalendarInstance();
		appCalendar.setTime(date);
		appCalendar.set(Calendar.SECOND, 0);
		appCalendar.set(Calendar.MILLISECOND, 0);		

		return appCalendar;
	}

	/**
	 * Method getAppCalendarInstanceForTimestampParm.
	 * @param request
	 * @return Calendar
	 */
	public static final java.util.Calendar getAppCalendarInstanceForTimestampParm(
		HttpServletRequest request) {
		java.util.Calendar calendar = getAppCalendarInstance();

		calendar.setTime(getDateFromTimestampParm(request));
		calendar.set(Calendar.SECOND, 0);
		calendar.set(Calendar.MILLISECOND, 0);		

		return calendar;
	}

	/**
	 * Method getDateFromTimestampParm.
	 * @param request
	 * @return Date
	 */
	public static final java.util.Date getDateFromTimestampParm(
		HttpServletRequest request) {
		String timestamp = request.getParameter(CalendarConstants.PARM_TIMESTAMP);

		// If no timestamp specified, default to today	
		if (timestamp == null) {
			return new java.util.Date();
		}
		else {
			return new java.util.Date(Long.parseLong(timestamp));
		}

	}

	/**
	 * Method getDayInfoForDay.
	 * @param dayInfos
	 * @param date
	 * @return DayInfo
	 */
	public static final DayInfo getDayInfoForDay(
		DayInfo[] dayInfos,
		Calendar date) {
		DayInfo dayInfo = null;
		int dayOfYear = date.get(Calendar.DAY_OF_YEAR);
		for (int i = 0;((i < dayInfos.length) && (dayInfo == null)); i++) {
			if (dayInfos[i].getCurrentDate().get(Calendar.DAY_OF_YEAR)
				== dayOfYear) {
				dayInfo = dayInfos[i];
			}
		}

		if (dayInfo == null) {
			dayInfo = new DayInfo(date);
		}

		return dayInfo;
	}

	/**
	 * Method getEventDAO.
	 * @return EventDAO
	 */
	public static final EventDAO getEventDAO() {
		return CalendarServletHelper.eventDAO;
	}


	/**
	 * Method getParameterAsInt.
	 * @param request
	 * @param parmName
	 * @return int
	 * @throws MissingServletParameterException
	 */
	public static final int getParameterAsInt(
		HttpServletRequest request,
		String parmName)
		throws MissingServletParameterException {
		String intAsString = request.getParameter(parmName);
		if (intAsString == null) {
			throw new MissingServletParameterException(parmName);
		}

		return new Integer(intAsString).intValue();
	}

	/**
	 * Method getParameterAsInt.
	 * @param request
	 * @param parmName
	 * @param defValue
	 * @return int
	 * @throws MissingServletParameterException
	 */
	public static final int getParameterAsInt(
		HttpServletRequest request,
		String parmName,
		int defValue)
		throws MissingServletParameterException {
		String intAsString = request.getParameter(parmName);
		int returnValue;
		if (intAsString == null) {
			returnValue = defValue;
		}
		else {
			returnValue = new Integer(intAsString).intValue();
		}

		return returnValue;
	}

	/**
	 * Method getParameterAsString.
	 * @param request
	 * @param parmName
	 * @return String
	 * @throws MissingServletParameterException
	 */
	public static final String getParameterAsString(
		HttpServletRequest request,
		String parmName)
		throws MissingServletParameterException {
		String returnValue = request.getParameter(parmName);
		if (returnValue == null) {
			throw new MissingServletParameterException(parmName);
		}

		return returnValue;
	}

	/**
	 * Method getParameterAsString.
	 * @param request
	 * @param parmName
	 * @param defaultValue
	 * @return String
	 */
	public static final String getParameterAsString(
		HttpServletRequest request,
		String parmName,
		String defaultValue) {
		String returnValue = request.getParameter(parmName);
		if (returnValue == null) {
			returnValue = defaultValue;
		}

		return returnValue;
	}

	/**
	 * Method getStartOfDayCalendarInstance.
	 * @param calendar
	 * @return Calendar
	 */
	public final static java.util.Calendar getStartOfDayCalendarInstance(
		java.util.Calendar calendar) {
		Calendar beginOfDateCalendar = (java.util.Calendar) calendar.clone();
		beginOfDateCalendar.set(Calendar.HOUR_OF_DAY, 0);
		beginOfDateCalendar.set(Calendar.MINUTE, 0);
		beginOfDateCalendar.set(Calendar.SECOND, 0);
		beginOfDateCalendar.set(Calendar.MILLISECOND, 0);
		return beginOfDateCalendar;
	}

	/**
	 * Method getEndOfDayCalendarInstance.
	 * @param calendar
	 * @return Calendar
	 */
	public final static java.util.Calendar getEndOfDayCalendarInstance(
		java.util.Calendar calendar) {
		Calendar endOfDateCalendar =
			CalendarServletHelper.getStartOfDayCalendarInstance(calendar);
		endOfDateCalendar.set(Calendar.HOUR_OF_DAY, 23);
		endOfDateCalendar.set(Calendar.MINUTE, 59);
		endOfDateCalendar.set(Calendar.SECOND, 59);
		endOfDateCalendar.set(Calendar.MILLISECOND, 999);

		return endOfDateCalendar;
	}
}