/* .COPYRIGHT:                                                                */
/*    Licensed Material - Program-Property of IBM                             */
/*    (C) Copyright IBM Corp. 2002 - All Rights Reserved                      */
/*                                                                            */
/* .DISCLAIMER:                                                               */
/*   The following [enclosed] code is sample code created by IBM              */
/*   Corporation.  This sample code is provided to you solely for use in      */
/*   connection with your internal evaluation of the Service Management       */
/*   Framework(TM) Toolkit (Program) during the term of Early Release license */
/*   for the Program, and for no other purpose.  The code is provided 'AS IS',*/
/*   without warranty of any kind.  IBM shall not be liable for any damages   */
/*   arising out of your use of the sample code, even if they have been       */
/*   advised of the possibility of such damages.                              */
package com.ibm.pvc.example.calendar.controller;

import java.util.Hashtable;

import com.ibm.pvc.example.calendar.CalendarConstants;
import com.ibm.pvc.example.calendar.InvalidActionRequestedException;

/**
 * This is the CalendarControllerFactory class.
 * 
 * This class is the factory used by the Front Controller (CalendarServlet)
 * to produce the controller required to handle a specfic action.
 */
public class CalendarControllerFactory {
	Hashtable controllers = null;

	/**
	 * @see java.lang.Object#Object()
	 */
	public CalendarControllerFactory() {
		super();
		loadFactory();
	}

	/**
	 * Method addControllerClassToHashtable.
	 * @param controllerClass
	 */
	public void addControllerClassToHashtable(Class controllerClass) {
		try {
			java.lang.reflect.Field actionField =
				controllerClass.getDeclaredField(CalendarConstants.FIELD_NAME_ACTION);
			String actionName = (String) actionField.get(controllerClass);
			controllers.put(actionName, controllerClass);

		}
		catch (Exception e) {
			// For this example app, this error will only be printed to System.out
			System.out.println("Exception Thrown Adding Class(" + controllerClass + ") to Hashtable");
			System.out.println(e);
		}
	}

	/**
	 * Method getControllerForAction.
	 * @param action
	 * @return CalendarController
	 * @throws InvalidActionRequestedException
	 */
	public CalendarController getControllerForAction(String action)
		throws InvalidActionRequestedException {
		CalendarController controller = null;
		try {
			Class controllerClass = (Class) controllers.get(action);
			controller = (CalendarController) controllerClass.newInstance();
		}
		catch (Exception e) {
			System.err.println(
				"Exception Thrown getting controller for action (" + action + ")");
			System.err.println(e);
			throw new InvalidActionRequestedException(action);
		}

		return controller;
	}

	/**
	 * Method loadFactory.
	 */
	public void loadFactory() {
		Class[] controllerClasses =
			{
				DayInfoController.class,
				WeekInfoController.class,
				MonthInfoController.class,
				DateSelectionController.class,
				NewEventController.class,
				UpdateEventController.class,
				DeleteEventController.class,
				SettingsController.class,
				FramesetController.class,
				HelpController.class,				
				CreateDbController.class };

		controllers = new Hashtable(controllerClasses.length);

		for (int i = 0; i < controllerClasses.length; i++) {
			addControllerClassToHashtable(controllerClasses[i]);
		}
	}
}