/* .COPYRIGHT:                                                                */
/*    Licensed Material - Program-Property of IBM                             */
/*    (C) Copyright IBM Corp. 2002 - All Rights Reserved                      */
/*                                                                            */
/* .DISCLAIMER:                                                               */
/*   The following [enclosed] code is sample code created by IBM              */
/*   Corporation.  This sample code is provided to you solely for use in      */
/*   connection with your internal evaluation of the Service Management       */
/*   Framework(TM) Toolkit (Program) during the term of Early Release license */
/*   for the Program, and for no other purpose.  The code is provided 'AS IS',*/
/*   without warranty of any kind.  IBM shall not be liable for any damages   */
/*   arising out of your use of the sample code, even if they have been       */
/*   advised of the possibility of such damages.                              */
package com.ibm.pvc.example.calendar.controller;

import javax.servlet.ServletException;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import com.ibm.pvc.example.calendar.CalendarConstants;
import com.ibm.pvc.example.calendar.CalendarServletException;
import com.ibm.pvc.example.calendar.CalendarServletHelper;
import com.ibm.pvc.example.calendar.model.Event;
import com.ibm.pvc.example.calendar.model.command.DayInfoCommand;
import com.ibm.pvc.example.calendar.model.command.DeleteEventCommand;
import com.ibm.pvc.example.calendar.model.command.GetEventCommand;
import com.ibm.pvc.example.calendar.view.DayInfoView;
import com.ibm.pvc.example.calendar.view.DeleteEventConfirmationView;
import com.ibm.pvc.example.command.CommandException;


/**
 * This is the DeleteEventController class.
 *
 * This controller class is responsible for handling deleting a specific
 * event based on its luid and then displaying the daily view corresponding 
 * to the deleted event's date, with the deleted event removed.
 * Note: This class is also responsible for displaying a deletion confirmation
 *       panel to the user prior to carrying out the deletion.
 * 
 */
public class DeleteEventController extends CalendarController {
	public static final String ACTION = "DeleteEvent";

	/**
	 * @see java.lang.Object#Object()
	 */
	public DeleteEventController() {
		super();
	}
	/**
	 * Method buildUrl.
	 * @param event
	 * @return String
	 */
	public static final String buildUrl(Event event) {
		return CalendarServletHelper.buildServletActionUrl(
			DeleteEventController.ACTION)
			+ CalendarServletHelper.buildServletUrlParmAddition(
				CalendarConstants.PARM_LUID,
				event.getLuid())
			+ CalendarServletHelper.buildServletUrlParmAddition(
				CalendarConstants.PARM_TIMESTAMP,
				event.getEvtStart().getTime().getTime());
	}

	/**
	 * @see com.ibm.pvc.example.calendar.controller.CalendarController#processRequest(HttpServletRequest, HttpServletResponse)
	 */
	public void processRequest(
		HttpServletRequest request,
		HttpServletResponse response)
		throws
			ServletException,
			java.io.IOException,
			CommandException,
			CalendarServletException {
		String luid = request.getParameter(CalendarConstants.PARM_LUID);
		String deleteConfirmed = request.getParameter("YES_DELETE");
		String deleteCancelled = request.getParameter("NO_DELETE");

		if ((deleteConfirmed != null) || (deleteCancelled != null)) {
			if (deleteConfirmed != null) {
				DeleteEventCommand command = new DeleteEventCommand();

				command.setLuid(new Integer(luid));

				command.execute();
			}

			DayInfoCommand dayInfoCommand = new DayInfoCommand();
			dayInfoCommand.setCurrentDate(
				CalendarServletHelper.getAppCalendarInstanceForTimestampParm(request));

			dayInfoCommand.execute();

			DayInfoView dayInfoView =
				new DayInfoView(dayInfoCommand.getCurrentDate(), dayInfoCommand.getDayInfo());

			dayInfoView.outputView(request, response);
		}
		else {
			GetEventCommand command = new GetEventCommand();

			command.setLuid(new Integer(luid));

			command.execute();

			DeleteEventConfirmationView view =
				new DeleteEventConfirmationView(command.getEvent());

			view.outputView(request, response);
		}

	}
}