/* .COPYRIGHT:                                                                */
/*    Licensed Material - Program-Property of IBM                             */
/*    (C) Copyright IBM Corp. 2002 - All Rights Reserved                      */
/*                                                                            */
/* .DISCLAIMER:                                                               */
/*   The following [enclosed] code is sample code created by IBM              */
/*   Corporation.  This sample code is provided to you solely for use in      */
/*   connection with your internal evaluation of the Service Management       */
/*   Framework(TM) Toolkit (Program) during the term of Early Release license */
/*   for the Program, and for no other purpose.  The code is provided 'AS IS',*/
/*   without warranty of any kind.  IBM shall not be liable for any damages   */
/*   arising out of your use of the sample code, even if they have been       */
/*   advised of the possibility of such damages.                              */
package com.ibm.pvc.example.calendar.controller;

import java.util.Calendar;

import javax.servlet.ServletException;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import javax.servlet.http.HttpSession;

import com.ibm.pvc.example.calendar.CalendarConstants;
import com.ibm.pvc.example.calendar.CalendarServletException;
import com.ibm.pvc.example.calendar.CalendarServletHelper;
import com.ibm.pvc.example.calendar.NoCurrentViewAvailableException;
import com.ibm.pvc.example.calendar.model.Event;
import com.ibm.pvc.example.calendar.model.EventCategories;
import com.ibm.pvc.example.calendar.model.command.DayInfoCommand;
import com.ibm.pvc.example.calendar.model.command.NewEventCommand;
import com.ibm.pvc.example.calendar.view.CalendarAppView;
import com.ibm.pvc.example.calendar.view.DayInfoView;
import com.ibm.pvc.example.calendar.view.ExceptionView;
import com.ibm.pvc.example.calendar.view.NewEventView;
import com.ibm.pvc.example.command.CommandException;

/**
 * This is the NewEventController class.
 * 
 * This controller class is responsible for displaying an Add Event form to
 * the user then executing the appropriated business logic to add the event
 * based on the user's input to the Calendar event database.  When the event
 * has been successfully added,the Daily view for the date of the newly created 
 * event is rendered.
 *   
 */
public class NewEventController extends CalendarController {
	public static final String ACTION = "NewEvent";

	/**
	 * @see java.lang.Object#Object()
	 */
	public NewEventController() {
		super();
	}
	/**
	 * Method buildUrl.
	 * @return String
	 */
	public static final String buildUrl() {
		return CalendarServletHelper.buildServletActionUrl(NewEventController.ACTION);
	}
	/**
	 * Method buildUrl.
	 * @param currentDate
	 * @return String
	 */
	public static final String buildUrl(java.util.Calendar currentDate) {
		return CalendarServletHelper.buildServletActionUrl(NewEventController.ACTION)
			+ CalendarServletHelper.buildServletUrlParmAddition(
				CalendarConstants.PARM_TIMESTAMP,
				currentDate);
	}
	/**
	 * Method buildUrl.
	 * @param currentDate
	 * @param duration
	 * @return String
	 */
	public static final String buildUrl(java.util.Calendar currentDate, int duration) {
		return CalendarServletHelper.buildServletActionUrl(NewEventController.ACTION)
			+ CalendarServletHelper.buildServletUrlParmAddition(
				CalendarConstants.PARM_TIMESTAMP,
				currentDate)
			+ CalendarServletHelper.buildServletUrlParmAddition(
				CalendarConstants.PARM_DURATION,
				duration);				
	}	

	/**
	 * Method createEventFromInputData.
	 * @param request
	 * @param response
	 * @return Event
	 * @throws ServletException
	 * @throws IOException
	 * @throws CommandException
	 * @throws CalendarServletException
	 */
	public Event createEventFromInputData(
		HttpServletRequest request,
		HttpServletResponse response)
		throws
			ServletException,
			java.io.IOException,
			CommandException,
			CalendarServletException {
		Event event = null;

		String summary = request.getParameter(CalendarConstants.PARM_SUMMARY),
			details = request.getParameter(CalendarConstants.PARM_DETAILS),
			eventType = request.getParameter("EventType"),
			month = request.getParameter("Month"),
			day = request.getParameter("Day"),
			year = request.getParameter("Year"),
			startHour = request.getParameter("StartHour"),
			startMinute = request.getParameter("StartMinute"),
			startAmPm = request.getParameter("StartAmPm"),
			duration = request.getParameter("Duration");
			
		EventCategories categories =
			new EventCategories(
				request.getParameterValues(CalendarConstants.PARM_CATEGORIES));
		Calendar evtStart = CalendarServletHelper.getAppCalendarInstance();
		Calendar evtEnd = null;
		evtStart.set(Calendar.YEAR, (new Integer(year)).intValue());
		evtStart.set(Calendar.MONTH, (new Integer(month)).intValue());
		evtStart.set(Calendar.DAY_OF_MONTH, (new Integer(day)).intValue());
		if (eventType.equals("TimedEvent")) {
			evtStart.set(Calendar.HOUR, (new Integer(startHour)).intValue());
			evtStart.set(Calendar.MINUTE, (new Integer(startMinute)).intValue());
			evtStart.set(Calendar.AM_PM, (startAmPm.equals("AM") ? Calendar.AM : Calendar.PM));
			evtEnd = (Calendar) evtStart.clone();
			evtEnd.add(Calendar.MINUTE, (new Integer(duration)).intValue());
		}
		return new Event(null, summary, details, evtStart, evtEnd, categories);
	}

	/**
	 * Method createEventWithDefaultValues.
	 * @param request
	 * @param response
	 * @return Event
	 * @throws ServletException
	 * @throws IOException
	 * @throws CommandException
	 * @throws CalendarServletException
	 */
	public Event createEventWithDefaultValues(
		HttpServletRequest request,
		HttpServletResponse response)
		throws
			ServletException,
			java.io.IOException,
			CommandException,
			CalendarServletException {
		Calendar evtStart =
			CalendarServletHelper.getAppCalendarInstanceForTimestampParm(request);

		Calendar evtEnd = null;	
		int
			duration = CalendarServletHelper.getParameterAsInt(request, CalendarConstants.PARM_DURATION, 0);
						
		if (duration != 0) {
			evtEnd = (Calendar) evtStart.clone();
			evtEnd.add(Calendar.MINUTE, duration);
		}

		return new Event(
			null,
			"",
			"",
			evtStart,
			evtEnd,
			new EventCategories(EventCategories.MEETING));
	}

	/**
	 * Method displayNewEventView.
	 * @param request
	 * @param response
	 * @throws ServletException
	 * @throws IOException
	 * @throws CommandException
	 * @throws CalendarServletException
	 */
	public void displayNewEventView(
		HttpServletRequest request,
		HttpServletResponse response)
		throws
			ServletException,
			java.io.IOException,
			CommandException,
			CalendarServletException {
		Event event = createEventWithDefaultValues(request, response);
		NewEventView view = new NewEventView(event);
		view.outputView(request, response);
	}

	/**
	 * @see com.ibm.pvc.example.calendar.controller.CalendarController#processRequest(HttpServletRequest, HttpServletResponse)
	 */
	public void processRequest(
		HttpServletRequest request,
		HttpServletResponse response)
		throws
			ServletException,
			java.io.IOException,
			CommandException,
			CalendarServletException {
		try {
			String submit = request.getParameter("SUBMIT");
			String cancel = request.getParameter("CANCEL");

			if (submit != null) {
				Event
					event = createEventFromInputData(request, response);
		
				NewEventCommand command = new NewEventCommand();		

				command.setEvent(event);
	
				command.execute();
	
				DayInfoCommand dayInfoCommand = new DayInfoCommand();
				
				dayInfoCommand.setCurrentDate(event.getEvtStart());

				dayInfoCommand.execute();

				DayInfoView dayInfoView =
					new DayInfoView(event.getEvtStart(), dayInfoCommand.getDayInfo());
	
				dayInfoView.outputView(request, response);
			}
			else if (cancel != null) {
				HttpSession session = request.getSession();
				
				CalendarAppView returnToView =
					(CalendarAppView) session.getValue(CalendarConstants.ATTR_RETURN_TO_VIEW);
				session.removeValue(CalendarConstants.ATTR_RETURN_TO_VIEW);
						
				returnToView.outputView(request, response);
			}				
			else {
				HttpSession session = request.getSession();
				CalendarAppView currentView =
 					(CalendarAppView) session.getValue(CalendarConstants.ATTR_CURRENT_VIEW);

				session.putValue(CalendarConstants.ATTR_RETURN_TO_VIEW,  currentView);
			
				if (currentView == null) {
					throw new NoCurrentViewAvailableException();
				}
				displayNewEventView(request, response);
			}
		}
		catch (Exception exception) {
			ExceptionView view = new ExceptionView(exception);
			view.outputView(request, response);
		}
	}
}