/* .COPYRIGHT:                                                                */
/*    Licensed Material - Program-Property of IBM                             */
/*    (C) Copyright IBM Corp. 2002 - All Rights Reserved                      */
/*                                                                            */
/* .DISCLAIMER:                                                               */
/*   The following [enclosed] code is sample code created by IBM              */
/*   Corporation.  This sample code is provided to you solely for use in      */
/*   connection with your internal evaluation of the Service Management       */
/*   Framework(TM) Toolkit (Program) during the term of Early Release license */
/*   for the Program, and for no other purpose.  The code is provided 'AS IS',*/
/*   without warranty of any kind.  IBM shall not be liable for any damages   */
/*   arising out of your use of the sample code, even if they have been       */
/*   advised of the possibility of such damages.                              */
package com.ibm.pvc.example.calendar.model;

import java.sql.Connection;
import java.sql.PreparedStatement;
import java.sql.ResultSet;
import java.sql.SQLException;
import java.sql.Statement;
import java.util.ArrayList;
import java.util.Calendar;

import com.ibm.pvc.example.calendar.CalendarServletHelper;


/**
 * This is the EventDAO class.
 * 
 * This class is the Data Access Object for the calendar's event backing store.
 */
public class EventDAO {

	/**
	 * @see java.lang.Object#Object()
	 */
	public EventDAO() {
		super();
	}
	/**
	 * Insert the method's description here.
	 * @param ev com.ibm.pvc.example.calendar.model.Event
	 */
	public int create(Event event) throws SQLException {
		Connection connection = null;
		int luid;

		try {
			connection = EventDbHelper.getConnection();
			luid = create(connection, event);
		}
		finally {
			DbHelper.closeConnection(connection);
		}
		return luid;
	}

	/**
	 * Method create.
	 * @param connection
	 * @param event
	 * @return int
	 * @throws SQLException
	 */
	private synchronized int create(Connection connection, Event event)
		throws SQLException {
		Statement statement = null;
		PreparedStatement preparedStatement = null;
		ResultSet resultSet = null;
		int luid = 1;

		Calendar
			evtStart = event.getEvtStart(),
			evtEnd   = event.getEvtEnd();
		// Since the granularity of events is minutes, clear out seconds/milliseconds
		if (evtStart != null) {
			evtStart.set(Calendar.SECOND, 0);
			evtStart.set(Calendar.MILLISECOND, 0);
		}
		if (evtEnd != null) {
			evtEnd.set(Calendar.SECOND, 0);
			evtEnd.set(Calendar.MILLISECOND, 0);
		}		

		try {
			statement = connection.createStatement();

			try {
				resultSet =
					statement.executeQuery(
						"SELECT MAX("
							+ EventDb.FIELD_LUID
							+ ") FROM "
							+ EventDb.TABLE_EVENT);

			} catch (java.sql.SQLException sqlException) {
				luid = 1;
			}
			if (resultSet != null) {
				if (resultSet.next() == true) {
					luid = resultSet.getInt(1) + 1;
				}
			}

			statement.close();
			statement = null;
			// close current statement before getting a prepared statement, since it will no longer be used

			preparedStatement =
				connection.prepareStatement(
							"INSERT INTO "
							+ EventDb.TABLE_EVENT
							+ "("
							+ EventDb.FIELD_LUID              // Int    1
							+ ", " + EventDb.FIELD_SUMMARY    // String 2
							+ ", " + EventDb.FIELD_DETAILS    // String 3
							+ ", " + EventDb.FIELD_EVT_START  // Date 4
							+ ", " + EventDb.FIELD_EVT_END    // Date   5
							+ ", " + EventDb.FIELD_CATEGORIES // String 6
							+ ") VALUES (?, ?, ?, ?, ?, ?)");

			preparedStatement.setInt(1, luid);
			preparedStatement.setString(2, event.getSummary());
			preparedStatement.setString(3, event.getDetails());
			preparedStatement.setTimestamp(
				4,
				EventDAO.getSqlTimestampInstance(event.getEvtStart()));
			preparedStatement.setTimestamp(
				5,
				EventDAO.getSqlTimestampInstance(event.getEvtEnd()));

			preparedStatement.setString(6, event.getCategories().asString());

			preparedStatement.executeUpdate();
		} finally {
			DbHelper.closeStatement(statement);
			DbHelper.closeStatement(preparedStatement);
		}

		return luid;
	}
	/**
	 * Method createEventObj.
	 * @param appCalendar
	 * @param luid
	 * @param summary
	 * @param details
	 * @param evtStart
	 * @param evtEnd
	 * @param categoriesString
	 * @param recRuleString
	 * @param recEnd
	 * @return Event
	 */
	private Event createEventObj(
		Calendar appCalendar,
		int luid,
		String summary,
		String details,
		java.sql.Timestamp evtStart,
		java.sql.Timestamp evtEnd,
		String categoriesString) {
		Calendar evtStartDate = null, evtEndDate = null;
		EventCategories categories = new EventCategories(categoriesString);
		if (evtStart != null) {
			evtStartDate = (Calendar) appCalendar.clone();
			evtStartDate.setTime(new java.util.Date(evtStart.getTime()));
			evtStartDate.set(Calendar.SECOND, 0);
			evtStartDate.set(Calendar.MILLISECOND, 0);			
		}
		if (evtEnd != null) {
			evtEndDate = (Calendar) appCalendar.clone();
			evtEndDate.setTime(new java.util.Date(evtEnd.getTime()));
			evtEndDate.set(Calendar.SECOND, 0);
			evtEndDate.set(Calendar.MILLISECOND, 0);			
		}
		Event 
			event =
				new Event(
					new Integer(luid),
					summary,
					details,
					evtStartDate,
					evtEndDate,
					categories);

		return event;
	}

	/**
	 * Method getEvent.
	 * @param luid
	 * @param appCalendar
	 * @return Event
	 * @throws SQLException
	 */
	public Event getEvent(Integer luid, Calendar appCalendar)
		throws java.sql.SQLException {
		Connection connection = null;
		PreparedStatement preparedStatement = null;
		Event event = null;

		try {
			connection = EventDbHelper.getConnection();
			preparedStatement =
				connection
					.prepareStatement("SELECT " + EventDb.FIELD_LUID        // Int 1
									+ ", " + EventDb.FIELD_SUMMARY          // String 2 
									+ ", " + EventDb.FIELD_DETAILS          // String 3     	
									+ ", " + EventDb.FIELD_EVT_START        // Timestamp 4   			  
									+ ", " + EventDb.FIELD_EVT_END          // Timestamp 5      	
									+ ", " + EventDb.FIELD_CATEGORIES       // String 6      
									+ " FROM " + EventDb.TABLE_EVENT
									+ " WHERE " + EventDb.FIELD_LUID + " = ? ");       // Parm 1 luid	                   		           

			preparedStatement.setInt(1, luid.intValue());

			ResultSet resultSet = preparedStatement.executeQuery();
			if (resultSet != null) {
				while (resultSet.next() == true) {
					event =
						createEventObj(
							appCalendar,
							resultSet.getInt(1),
							resultSet.getString(2),
							resultSet.getString(3),
							resultSet.getTimestamp(4),
							resultSet.getTimestamp(5),
							resultSet.getString(6));
				}
			}

		}
		finally {
			DbHelper.closeStatement(preparedStatement);
			DbHelper.closeConnection(connection);
		}

		return event;
	}

	/**
	 * Method getEventsForDate.
	 * @param date
	 * @return Event[]
	 * @throws SQLException
	 */
	public Event[] getEventsForDate(java.util.Calendar date)
		throws java.sql.SQLException {
		return getEventsForRange(
			CalendarServletHelper.getStartOfDayCalendarInstance(date),
			CalendarServletHelper.getEndOfDayCalendarInstance(date));
	}

	/**
	 * Method getEventsForDates.
	 * @param startDate
	 * @param endDate
	 * @return Event[]
	 * @throws SQLException
	 */
	public Event[] getEventsForDates(
		java.util.Calendar startDate,
		java.util.Calendar endDate)
		throws java.sql.SQLException {
							
		return getEventsForRange(
			CalendarServletHelper.getStartOfDayCalendarInstance(startDate),
			CalendarServletHelper.getEndOfDayCalendarInstance(endDate));
	}

	/**
	 * Method getEventsForRange.
	 * @param rangeBegin
	 * @param rangeEnd
	 * @return Event[]
	 * @throws SQLException
	 */
	public Event[] getEventsForRange(
		java.util.Calendar rangeBegin,
		java.util.Calendar rangeEnd)
		throws java.sql.SQLException {
		ArrayList eventsList = new ArrayList();

		Connection connection = null;
		PreparedStatement preparedStatement = null;

		try {
			java.sql.Timestamp 
				tsEvtBegin = EventDAO.getSqlTimestampInstance(rangeBegin),
				tsEvtEnd = EventDAO.getSqlTimestampInstance(rangeEnd);
			connection = EventDbHelper.getConnection();
			
			preparedStatement =
				connection
					.prepareStatement("SELECT " + EventDb.FIELD_LUID     // Int 1
									+ ", " + EventDb.FIELD_SUMMARY       // String 2 
									+ ", " + EventDb.FIELD_DETAILS       // String 3     		
									+ ", " + EventDb.FIELD_EVT_START     // Timestamp 4     
									+ ", " + EventDb.FIELD_EVT_END       // Timestamp 5      
									+ ", " + EventDb.FIELD_CATEGORIES    // String 6      
									+ " FROM " + EventDb.TABLE_EVENT
									+ " WHERE ("
									+ EventDb.FIELD_EVT_START + " >= ? "                // Parm 1 begin
									+ " AND " + EventDb.FIELD_EVT_START + " <= ? )"     // Parm 2 end		                           		               
									+ " OR " + "(" + EventDb.FIELD_EVT_END + " >= ? "   // Parm 3 begin
									+ " AND " + EventDb.FIELD_EVT_END + " <= ? )"       // Parm 4 end	
									+ " OR " + "(" + EventDb.FIELD_EVT_START + " <= ? " // Parm 5 begin
									+ " AND " + EventDb.FIELD_EVT_END + " >= ? )");     // Parm 6 end					                           		                

			preparedStatement.setTimestamp(1, tsEvtBegin);
			preparedStatement.setTimestamp(2, tsEvtEnd);
			preparedStatement.setTimestamp(3, tsEvtBegin);
			preparedStatement.setTimestamp(4, tsEvtEnd);
			preparedStatement.setTimestamp(5, tsEvtBegin);
			preparedStatement.setTimestamp(6, tsEvtEnd);

			ResultSet resultSet = preparedStatement.executeQuery();
			if (resultSet != null) {
				while (resultSet.next() == true) {
					eventsList.add(
						createEventObj(
							rangeBegin,
							resultSet.getInt(1),
							resultSet.getString(2),
							resultSet.getString(3),
							resultSet.getTimestamp(4),
							resultSet.getTimestamp(5),
							resultSet.getString(6)));

				}
			}

		}
		finally {
			DbHelper.closeStatement(preparedStatement);
			DbHelper.closeConnection(connection);
		}

		Event[] events = new Event[eventsList.size()];

		events = (Event[]) eventsList.toArray(events);
		return events;
	}

	/**
	 * Method getSqlTimestampInstance.
	 * @param calendar
	 * @return Timestamp
	 */
	public final static java.sql.Timestamp getSqlTimestampInstance(
		java.util.Calendar calendar) {
		return (
			(calendar == null)
				? null
				: new java.sql.Timestamp(calendar.getTime().getTime()));
	}
	/**
	 * Method remove.
	 * @param eventLuid
	 * @param subDate
	 */
	public void remove(int eventLuid, java.util.Calendar subDate)  {
	}
 
	/**
	 * Method remove.
	 * @param luid
	 * @throws SQLException
	 */
	public void remove(Integer luid) throws SQLException {
		Connection dbConnection = null;
		PreparedStatement statement = null;
		try {

			//connect to database
			dbConnection = EventDbHelper.getConnection();
			statement =
				dbConnection.prepareStatement(
					"DELETE FROM " + EventDb.TABLE_EVENT + " WHERE " + EventDb.FIELD_LUID + "= ?");
			statement.setInt(1, luid.intValue());
			statement.executeUpdate(); 
		}
		finally {
			DbHelper.closeStatement(statement);
			DbHelper.closeConnection(dbConnection);
		}
	}
 
	/**
	 * Method update.
	 * @param event
	 * @throws SQLException
	 */
	public void update(Event event) throws SQLException {
		Connection connection = null;
		int luid;

		try {
			connection = EventDbHelper.getConnection();
			update(connection, event);
		}
		finally {
			DbHelper.closeConnection(connection);
		}
	}
 
	/**
	 * Method update.
	 * @param connection
	 * @param event
	 * @throws SQLException
	 */
	private synchronized void update(Connection connection, Event event)
		throws SQLException {
		PreparedStatement preparedStatement = null;
		ResultSet resultSet = null;
		Calendar
			evtStart = event.getEvtStart(),
			evtEnd   = event.getEvtEnd();		
		// Since the granularity of events is minutes, clear out seconds/milliseconds
		if (evtStart != null) {
			evtStart.set(Calendar.SECOND, 0);
			evtStart.set(Calendar.MILLISECOND, 0);
		}
		if (evtEnd != null) {
			evtEnd.set(Calendar.SECOND, 0);
			evtEnd.set(Calendar.MILLISECOND, 0);
		}				
		
		try {
				preparedStatement =
					connection
						.prepareStatement(
							"UPDATE "
							+ EventDb.TABLE_EVENT
							+ " SET " 	+ EventDb.FIELD_SUMMARY
							+ " = ? "                                     // String 1
							+ ", " + EventDb.FIELD_DETAILS + " = ? "      // String 2
							+ ", " + EventDb.FIELD_EVT_START + " = ? "    // Timestamp 3
							+ ", " + EventDb.FIELD_EVT_END + " = ? "      // Timestamp 4
							+ ", " + EventDb.FIELD_CATEGORIES + " = ? "   // String 5
							+ " WHERE " + EventDb.FIELD_LUID + " = ? ");  // Int 6

			preparedStatement.setString(1, event.getSummary());
			preparedStatement.setString(2, event.getDetails());
			preparedStatement.setTimestamp(
				3,
				EventDAO.getSqlTimestampInstance(event.getEvtStart()));
			preparedStatement.setTimestamp(
				4,
				EventDAO.getSqlTimestampInstance(event.getEvtEnd()));

			preparedStatement.setString(5, event.getCategories().asString());
			preparedStatement.setInt(6, event.getLuid().intValue());
			
			preparedStatement.executeUpdate();			
		}
		finally {
			DbHelper.closeStatement(preparedStatement);
		}
	}
}