/* .COPYRIGHT:                                                                */
/*    Licensed Material - Program-Property of IBM                             */
/*    (C) Copyright IBM Corp. 2002 - All Rights Reserved                      */
/*                                                                            */
/* .DISCLAIMER:                                                               */
/*   The following [enclosed] code is sample code created by IBM              */
/*   Corporation.  This sample code is provided to you solely for use in      */
/*   connection with your internal evaluation of the Service Management       */
/*   Framework(TM) Toolkit (Program) during the term of Early Release license */
/*   for the Program, and for no other purpose.  The code is provided 'AS IS',*/
/*   without warranty of any kind.  IBM shall not be liable for any damages   */
/*   arising out of your use of the sample code, even if they have been       */
/*   advised of the possibility of such damages.                              */
package com.ibm.pvc.example.calendar.model;

/**
 * This is the MutableSettings class.
 * 
 * This class provides a mutable object for both getting and setting 
 * data values for the settings object.
 */
public class MutableSettings extends Settings {

	/**
	 * @see java.lang.Object#Object()
	 */
	public MutableSettings() {
		super();
	}

	/**
	 * Method MutableSettings.
	 * @param settings
	 */
	public MutableSettings(Settings settings) {
		super();
		this.dailyTimeGridFirstHour = settings.getDailyTimeGridFirstHour();
		this.dailyTimeGridLastHour = settings.getDailyTimeGridLastHour();
		this.defaultAction = settings.getDefaultAction();
		this.showDailyTimeGrid = settings.isShowDailyTimeGrid();
		this.titlesBgColor = settings.titlesBgColor;
		this.titlesFgColor = settings.titlesFgColor;
		this.overflowSupported  = settings.overflowSupported;	
	}
	
	/**
	 * Method setDailyTimeGridFirstHour.
	 * @param newTimeGridFirstHour
	 * @throws IllegalArgumentException
	 */
	public void setDailyTimeGridFirstHour(int newTimeGridFirstHour)
		throws java.lang.IllegalArgumentException {
		if ((newTimeGridFirstHour < 0) || (newTimeGridFirstHour > 23))
			throw new java.lang.IllegalArgumentException();
		dailyTimeGridFirstHour = newTimeGridFirstHour;
	}

	/**
	 * Method setDailyTimeGridLastHour.
	 * @param newTimeGridLastHour
	 * @throws IllegalArgumentException
	 */
	public void setDailyTimeGridLastHour(int newTimeGridLastHour)
		throws java.lang.IllegalArgumentException {
		if ((newTimeGridLastHour < 0) || (newTimeGridLastHour > 23))
			throw new java.lang.IllegalArgumentException();
		dailyTimeGridLastHour = newTimeGridLastHour;
	}

	/**
	 * Method setDefaultAction.
	 * @param newDefaultAction
	 * @throws IllegalArgumentException
	 */
	public void setDefaultAction(java.lang.String newDefaultAction)
		throws java.lang.IllegalArgumentException {
		boolean validAction = false;
		for (int i = 0;
			((i < Settings.VALID_DEFAULT_ACTIONS.length) && (validAction == false));
			i++) {
			if (Settings.VALID_DEFAULT_ACTIONS[i].equals(newDefaultAction)) {
				validAction = true;
			}
		}
		if (!validAction)
			throw new java.lang.IllegalArgumentException();
		this.defaultAction = newDefaultAction;
	}

	/**
	 * Method setShowDailyTimeGrid.
	 * @param newShowDailyTimeGrid
	 */
	public void setShowDailyTimeGrid(boolean newShowDailyTimeGrid) {
		this.showDailyTimeGrid = newShowDailyTimeGrid;
	}

	/**
	 * Method setTitlesBgColor.
	 * @param newTitlesBgColor
	 */
	public void setTitlesBgColor(String newTitlesBgColor) {
		this.titlesBgColor = newTitlesBgColor;
	}

	/**
	 * Method setTitlesFgColor.
	 * @param newTitlesFgColor
	 */
	public void setTitlesFgColor(String newTitlesFgColor) {
		this.titlesFgColor = newTitlesFgColor;
	}
	
	/**
	 * Method setOverflowSupported.
	 * @param newOverflowSupported
	 */
	public void setOverflowSupported(boolean newOverflowSupported) {
		this.overflowSupported = newOverflowSupported;
	}		

}