/* .COPYRIGHT:                                                                */
/*    Licensed Material - Program-Property of IBM                             */
/*    (C) Copyright IBM Corp. 2002 - All Rights Reserved                      */
/*                                                                            */
/* .DISCLAIMER:                                                               */
/*   The following [enclosed] code is sample code created by IBM              */
/*   Corporation.  This sample code is provided to you solely for use in      */
/*   connection with your internal evaluation of the Service Management       */
/*   Framework(TM) Toolkit (Program) during the term of Early Release license */
/*   for the Program, and for no other purpose.  The code is provided 'AS IS',*/
/*   without warranty of any kind.  IBM shall not be liable for any damages   */
/*   arising out of your use of the sample code, even if they have been       */
/*   advised of the possibility of such damages.                              */
package com.ibm.pvc.example.calendar.model;

import com.ibm.pvc.example.calendar.CalendarConstants;
import com.ibm.pvc.example.calendar.controller.DayInfoController;
import com.ibm.pvc.example.calendar.controller.MonthInfoController;
import com.ibm.pvc.example.calendar.controller.SettingsController;
import com.ibm.pvc.example.calendar.controller.WeekInfoController;

/**
 * This is the Settings class.
 * 
 * This class provides an non-mutable object for getting for the settings object. 
 */
public class Settings {
	protected boolean showDailyTimeGrid;
	protected int dailyTimeGridFirstHour;
	protected int dailyTimeGridLastHour;
	protected java.lang.String defaultAction;
	protected java.lang.String titlesBgColor;
	protected java.lang.String titlesFgColor;
	protected boolean overflowSupported;

	protected static String[] VALID_DEFAULT_ACTIONS =
		{
			DayInfoController.ACTION,
			WeekInfoController.ACTION,
			MonthInfoController.ACTION,
			SettingsController.ACTION };

	protected static String[] VALID_COLORS =
		{
			CalendarConstants.HTML_COLOR_AQUA,
			CalendarConstants.HTML_COLOR_BLACK,
			CalendarConstants.HTML_COLOR_BLUE,
			CalendarConstants.HTML_COLOR_FUCHSIA,
			CalendarConstants.HTML_COLOR_GREEN,
			CalendarConstants.HTML_COLOR_GRAY,
			CalendarConstants.HTML_COLOR_LIME,
			CalendarConstants.HTML_COLOR_MAROON,
			CalendarConstants.HTML_COLOR_NAVY,
			CalendarConstants.HTML_COLOR_OLIVE,
			CalendarConstants.HTML_COLOR_PURPLE,
			CalendarConstants.HTML_COLOR_RED,
			CalendarConstants.HTML_COLOR_SILVER,
			CalendarConstants.HTML_COLOR_TEAL,
			CalendarConstants.HTML_COLOR_WHITE,
			CalendarConstants.HTML_COLOR_YELLOW };

	/**
	 * @see java.lang.Object#Object()
	 */
	public Settings() {
		super();
	}

	/**
	 * Method getTitlesBgColor.
	 * @return String
	 */
	public String getTitlesBgColor() {
		return titlesBgColor;
	}

	/**
	 * Method getTitlesFgColor.
	 * @return String
	 */
	public String getTitlesFgColor() {
		return titlesFgColor;
	}

	/**
	 * Method getDailyTimeGridFirstHour.
	 * @return int
	 */
	public int getDailyTimeGridFirstHour() {
		return dailyTimeGridFirstHour;
	}

	/**
	 * Method getDailyTimeGridLastHour.
	 * @return int
	 */
	public int getDailyTimeGridLastHour() {
		return dailyTimeGridLastHour;
	}

	/**
	 * Method getDefaultAction.
	 * @return String
	 */
	public java.lang.String getDefaultAction() {
		return defaultAction;
	}

	/**
	 * Method isShowDailyTimeGrid.
	 * @return boolean
	 */
	public boolean isShowDailyTimeGrid() {
		return showDailyTimeGrid;
	}

	/**
	 * Method isOverflowSupported.
	 * @return boolean
	 */
	public boolean isOverflowSupported() {
		return overflowSupported;
	}

	/**
	 * @see java.lang.Object#toString()
	 */
	public String toString() {
		return "Settings["
			+ "showDailyTimeGrid("
			+ showDailyTimeGrid
			+ "), "
			+ "dailyTimeGridFirstHour("
			+ dailyTimeGridFirstHour
			+ "), "
			+ "dailyTimeGridLastHour("
			+ dailyTimeGridLastHour
			+ "), "
				+ "defaultAction("
			+ defaultAction
			+ "), "
			+ "titlesBgColor("
			+ titlesBgColor
			+ "), "				
			+ "titlesFgColor("
			+ titlesFgColor
			+ "), "				
			+ "overflowSupported("
			+ overflowSupported
			+ ")"
			+ "]";
	}
}