/* .COPYRIGHT:                                                                */
/*    Licensed Material - Program-Property of IBM                             */
/*    (C) Copyright IBM Corp. 2002 - All Rights Reserved                      */
/*                                                                            */
/* .DISCLAIMER:                                                               */
/*   The following [enclosed] code is sample code created by IBM              */
/*   Corporation.  This sample code is provided to you solely for use in      */
/*   connection with your internal evaluation of the Service Management       */
/*   Framework(TM) Toolkit (Program) during the term of Early Release license */
/*   for the Program, and for no other purpose.  The code is provided 'AS IS',*/
/*   without warranty of any kind.  IBM shall not be liable for any damages   */
/*   arising out of your use of the sample code, even if they have been       */
/*   advised of the possibility of such damages.                              */
package com.ibm.pvc.example.calendar.model;

import java.util.Properties;

import com.ibm.pvc.example.calendar.CalendarConstants;
import com.ibm.pvc.example.calendar.controller.DayInfoController;

/**
 * This is the SettingsDAO class.
 * 
 * This is the Data Access Object for the application settings.
 * Note: For this sample application, the settings are transient and not store
 *       in an external backing store.   
 */
public class SettingsDAO {
	private static Settings cachedSettingsObject;

	/**
	 * @see java.lang.Object#Object()
	 */
	public SettingsDAO() {
		super();
	}

	/**
	 * Method createInitialSettingsObject.
	 * @return Settings
	 */
	public final static Settings createInitialSettingsObject() {
		MutableSettings mSettings = new MutableSettings();
		mSettings.setShowDailyTimeGrid(true);		
		mSettings.setDailyTimeGridFirstHour(8);
		mSettings.setDailyTimeGridLastHour(18);
		mSettings.setDefaultAction(DayInfoController.ACTION);
		mSettings.setTitlesBgColor(CalendarConstants.HTML_COLOR_YELLOW);
		mSettings.setTitlesFgColor(CalendarConstants.HTML_COLOR_BLACK);
		mSettings.setOverflowSupported(false);						
		return (Settings) mSettings;
	}

	/**
	 * Method getAppSettings.
	 * @return Settings
	 */
	public final static Settings getAppSettings() {
		if (cachedSettingsObject == null) {
			cachedSettingsObject = createInitialSettingsObject();
		}
		return cachedSettingsObject;
	}

	/**
	 * Method getMutableSettings.
	 * @return MutableSettings
	 */
	public final static MutableSettings getMutableSettings() {
		return new MutableSettings(SettingsDAO.getAppSettings());
	}

	/**
	 * Method store.
	 * @param settings
	 */
	public final static void store(MutableSettings settings) {
 		SettingsDAO.cachedSettingsObject = (Settings) settings;
 		// For purposes of this sample code, changes to the Settings Object are 
 		// not persisted.
	}
}