/* .COPYRIGHT:                                                                */
/*    Licensed Material - Program-Property of IBM                             */
/*    (C) Copyright IBM Corp. 2002 - All Rights Reserved                      */
/*                                                                            */
/* .DISCLAIMER:                                                               */
/*   The following [enclosed] code is sample code created by IBM              */
/*   Corporation.  This sample code is provided to you solely for use in      */
/*   connection with your internal evaluation of the Service Management       */
/*   Framework(TM) Toolkit (Program) during the term of Early Release license */
/*   for the Program, and for no other purpose.  The code is provided 'AS IS',*/
/*   without warranty of any kind.  IBM shall not be liable for any damages   */
/*   arising out of your use of the sample code, even if they have been       */
/*   advised of the possibility of such damages.                              */
package com.ibm.pvc.example.calendar.model.command;

import com.ibm.pvc.example.calendar.CalendarServletHelper;
import com.ibm.pvc.example.calendar.model.DayInfo;
import com.ibm.pvc.example.calendar.model.Event;
import com.ibm.pvc.example.command.Command;
import com.ibm.pvc.example.command.CommandException;

/**
 * This is the DayInfoCommand class.
 * 
 * This class is responsible for retrieving all the events for a specific date.
 * 
 * Prior to running the execute command the caller must set currentDate to the date to  
 * retrieve information for.  After the execute method completes, the caller should 
 * retrieve the results in the dayInfo object.
 */
public class DayInfoCommand implements Command {
	private java.util.Calendar currentDate;
	private DayInfo dayInfo;

	/**
	 * @see java.lang.Object#Object()
	 */
	public DayInfoCommand() {
		super();
	}

	/**
	 * @see com.ibm.pvc.example.command.Command#execute()
	 */
	public void execute() throws com.ibm.pvc.example.command.CommandException {

		try {
			dayInfo = new DayInfo(currentDate);

			Event[] events =
				CalendarServletHelper.getEventDAO().getEventsForDate(currentDate);

			for (int i = 0; i < events.length; i++) {
				dayInfo.addEvent(events[i]);
			}
		}
		catch (Exception ex) {
			CommandException
				ce = new CommandException(ex.toString());
			throw (CommandException)ce.fillInStackTrace();
		}
	}

	/**
	 * Method getCurrentDate.
	 * @return Calendar
	 */
	public java.util.Calendar getCurrentDate() {
		return currentDate;
	}

	/**
	 * Method getDayInfo.
	 * @return DayInfo
	 */
	public DayInfo getDayInfo() {
		return this.dayInfo;
	}

	/**
	 * Method setCurrentDate.
	 * @param newCurrentDate
	 */
	public void setCurrentDate(java.util.Calendar newCurrentDate) {
		this.currentDate = newCurrentDate;
	}
}