/* .COPYRIGHT:                                                                */
/*    Licensed Material - Program-Property of IBM                             */
/*    (C) Copyright IBM Corp. 2002 - All Rights Reserved                      */
/*                                                                            */
/* .DISCLAIMER:                                                               */
/*   The following [enclosed] code is sample code created by IBM              */
/*   Corporation.  This sample code is provided to you solely for use in      */
/*   connection with your internal evaluation of the Service Management       */
/*   Framework(TM) Toolkit (Program) during the term of Early Release license */
/*   for the Program, and for no other purpose.  The code is provided 'AS IS',*/
/*   without warranty of any kind.  IBM shall not be liable for any damages   */
/*   arising out of your use of the sample code, even if they have been       */
/*   advised of the possibility of such damages.                              */
package com.ibm.pvc.example.calendar.model.command;

import java.sql.SQLException;

import com.ibm.pvc.example.calendar.CalendarServletHelper;
import com.ibm.pvc.example.calendar.model.EventDAO;
import com.ibm.pvc.example.command.Command;
import com.ibm.pvc.example.command.CommandSQLException;

/**
 * This is the DeleteEventCommand class.
 * 
 * This class is responsible for delete an event from the Calendar Servlet's event database.
 * 
 * Prior to running the execute command the caller must set luid of the event to be deleted.
 */
public class DeleteEventCommand implements Command {
	private Integer luid;

	/**
	 * @see java.lang.Object#Object()
	 */
	public DeleteEventCommand() {
		super();
	}

	/**
	 * @see com.ibm.pvc.example.command.Command#execute()
	 */
	public void execute() throws com.ibm.pvc.example.command.CommandException {
		try {
			EventDAO eventDAO = CalendarServletHelper.getEventDAO();

			eventDAO.remove(luid);
		}
		catch (SQLException sqlException) {
			throw new CommandSQLException(sqlException);
		}
	}

	/**
	 * Method getLuid.
	 * @return Integer
	 */
	public Integer getLuid() {
		return luid;
	}

	/**
	 * Method setLuid.
	 * @param newLuid
	 */
	public void setLuid(Integer newLuid) {
		luid = newLuid;
	}
}