/* .COPYRIGHT:                                                                */
/*    Licensed Material - Program-Property of IBM                             */
/*    (C) Copyright IBM Corp. 2002 - All Rights Reserved                      */
/*                                                                            */
/* .DISCLAIMER:                                                               */
/*   The following [enclosed] code is sample code created by IBM              */
/*   Corporation.  This sample code is provided to you solely for use in      */
/*   connection with your internal evaluation of the Service Management       */
/*   Framework(TM) Toolkit (Program) during the term of Early Release license */
/*   for the Program, and for no other purpose.  The code is provided 'AS IS',*/
/*   without warranty of any kind.  IBM shall not be liable for any damages   */
/*   arising out of your use of the sample code, even if they have been       */
/*   advised of the possibility of such damages.                              */
package com.ibm.pvc.example.calendar.model.command;

import java.sql.SQLException;
import java.util.Calendar;

import com.ibm.pvc.example.calendar.CalendarServletHelper;
import com.ibm.pvc.example.calendar.model.DayInfo;
import com.ibm.pvc.example.calendar.model.Event;
import com.ibm.pvc.example.calendar.model.EventDAO;
import com.ibm.pvc.example.command.Command;
import com.ibm.pvc.example.command.CommandSQLException;

/**
 * This is the WeekInfoCommand class.
 * 
 * This class is responsible for retrieving all the events for a specific week.
 * 
 * Prior to running the execute command the caller must set currentDate to a date in
 * in the week to retrieve information for.  After the execute method completes, 
 * the caller should retrieve the results in the dayInfos object.  
 */
public class WeekInfoCommand implements Command {
	private java.util.Calendar currentDate;

	private DayInfo[] dayInfos;
	/**
	 * @see java.lang.Object#Object()
	 */
	/**
	 * WeekInfoCommand constructor comment.
	 */
	public WeekInfoCommand() {
		super();
	}

	/**
	 * @see com.ibm.pvc.example.command.Command#execute()
	 */
	public void execute() throws com.ibm.pvc.example.command.CommandException {
		Calendar firstDay = (Calendar) currentDate.clone(),
			lastDay = (Calendar) currentDate.clone();

		firstDay.set(
			Calendar.DAY_OF_WEEK,
			currentDate.getMinimum(Calendar.DAY_OF_WEEK));
		lastDay.set(Calendar.DAY_OF_WEEK, currentDate.getMaximum(Calendar.DAY_OF_WEEK));

		try {
			EventDAO eventDAO = CalendarServletHelper.getEventDAO();

			Event[] events = eventDAO.getEventsForDates(firstDay, lastDay);

			dayInfos = CalendarServletHelper.createDayInfos(events, firstDay, lastDay);
		}
		catch (SQLException sqlException) {
			throw new CommandSQLException(sqlException);
		}

	}

	/**
	 * Method getCurrentDate.
	 * @return Calendar
	 */
	public java.util.Calendar getCurrentDate() {
		return this.currentDate;
	}

	/**
	 * Method getDayInfos.
	 * @return DayInfo[]
	 */
	public DayInfo[] getDayInfos() {
		return this.dayInfos;
	}

	/**
	 * Method setCurrentDate.
	 * @param newCurrentDate
	 */
	public void setCurrentDate(java.util.Calendar newCurrentDate) {
		this.currentDate = newCurrentDate;
	}
}