/* .COPYRIGHT:                                                                */
/*    Licensed Material - Program-Property of IBM                             */
/*    (C) Copyright IBM Corp. 2002 - All Rights Reserved                      */
/*                                                                            */
/* .DISCLAIMER:                                                               */
/*   The following [enclosed] code is sample code created by IBM              */
/*   Corporation.  This sample code is provided to you solely for use in      */
/*   connection with your internal evaluation of the Service Management       */
/*   Framework(TM) Toolkit (Program) during the term of Early Release license */
/*   for the Program, and for no other purpose.  The code is provided 'AS IS',*/
/*   without warranty of any kind.  IBM shall not be liable for any damages   */
/*   arising out of your use of the sample code, even if they have been       */
/*   advised of the possibility of such damages.                              */
package com.ibm.pvc.example.calendar.view;

import java.text.DateFormat;
import java.util.Calendar;

import javax.servlet.ServletOutputStream;

import com.ibm.pvc.example.calendar.controller.DayInfoController;
import com.ibm.pvc.example.calendar.controller.NewEventController;
import com.ibm.pvc.example.calendar.controller.UpdateEventController;
import com.ibm.pvc.example.calendar.model.DayInfo;
import com.ibm.pvc.example.calendar.model.Event;
import com.ibm.pvc.example.calendar.model.Settings;
import com.ibm.pvc.example.calendar.model.SettingsDAO;

/**
 * This is the DayInfoView class.
 * 
 * This class handles the rendering of the 1/4 VGA Daily View in the Calendar Servlet.
 * 
 * Instances of this class are contructed with both the current day to render 
 * and all the information to be displayed for that day passed as parameters.
 */
public class DayInfoView extends CalendarAppView {
	private java.util.Calendar currentDate;
	private DayInfo dayInfo;

	/**
	 * Method DayInfoView.
	 * @param currentDate
	 * @param dayInfo
	 */
	public DayInfoView(Calendar currentDate, DayInfo dayInfo) {
		super();
		this.currentDate = currentDate;
		this.dayInfo = dayInfo;
	}
	/**
	 * @see com.ibm.pvc.example.calendar.view.CalendarAppView#getTitle()
	 */
	protected String getTitle() {
		return DateFormat.getDateInstance(DateFormat.FULL).format(
			currentDate.getTime());
	}
	/**
	 * @see com.ibm.pvc.example.calendar.view.CalendarAppView#outputViewContent(ServletOutputStream)
	 */
	protected void outputViewContent(ServletOutputStream out)
		throws java.io.IOException {
		Settings settings = SettingsDAO.getAppSettings();

		if (settings.isShowDailyTimeGrid() == true) {
			outputViewContentWithTimeGrid(
				out,
				settings.getDailyTimeGridFirstHour(),
				settings.getDailyTimeGridLastHour());
		}
		else {
			outputViewContentWithoutTimeGrid(out);
		}
	}

	/**
	 * Method outputGridTimeLink.
	 * @param out
	 * @param linkCal
	 * @param duration
	 * @throws IOException
	 */
	private void outputGridTimeLink(
		ServletOutputStream out,
		Calendar linkCal,
		int duration) 
		throws java.io.IOException {
		DateFormat dfTime = DateFormat.getTimeInstance(DateFormat.SHORT);	
				
		out.print("<A HREF=\"");
		out.print(NewEventController.buildUrl(linkCal, duration));
		out.print("\" TARGET=\"_top\">");
		out.print(((duration == 0) ? Resources.getNlsString(Resources.VAL_DUR_ALL_DAY) : dfTime.format(linkCal.getTime())));	
 		out.println("</A>");
	}	
	/**
	 * Method outputViewContentWithTimeGrid.
	 * @param out
	 * @param gridFirstHour
	 * @param gridLastHour
	 * @throws IOException
	 */
	protected void outputViewContentWithTimeGrid(
		ServletOutputStream out,
		int gridFirstHour,
		int gridLastHour)
		throws java.io.IOException {
		Event[] allDayEvents = dayInfo.getAllDayEvents();
		Event[] timedEvents = dayInfo.getChronologicalTimedEvents();
		int viewDayOfYear = currentDate.get(Calendar.DAY_OF_YEAR);
		DateFormat dfTime = DateFormat.getTimeInstance(DateFormat.SHORT);
		Event event;
		String iconName = null;
		Calendar gridHourBegin = (Calendar) currentDate.clone();
		gridHourBegin.set(Calendar.HOUR_OF_DAY, gridFirstHour);
		gridHourBegin.set(Calendar.MINUTE, 0);
		gridHourBegin.set(Calendar.SECOND, 0);
		gridHourBegin.set(Calendar.MILLISECOND, 0);
		Calendar gridHourEnd = (Calendar) gridHourBegin.clone();
		gridHourEnd.add(Calendar.HOUR_OF_DAY, 1);

		out.println("<TABLE BORDER=0>");
		out.print("<TR><TD COLSPAN=7 ALIGN=LEFT>");
		outputGridTimeLink(out, gridHourBegin, 0);		
		out.println("</TD><TR>");
		for (int i = 0; i < allDayEvents.length; i++) {
			event = allDayEvents[i];
			iconName = CalendarAppView.getIconNameForCategory(event.getCategories());
			out.print("<TR><TD COLSPAN=3 ALIGN=CENTER>" + (i + 1) + "</TD><TD><IMG BORDER=0 SRC=\"/PIMImages/");
			out.print(iconName);
			out.print("\"></TD><TD>&nbsp;</TD><TD><A HREF=\"");
			out.print(UpdateEventController.buildUrl(event));
			out.print("\" TARGET=\"_top\">");
   			CalendarAppView.outputEncodedDataValue(out, (((event.getSummary() != null) && (!event.getSummary().equals(""))) ? event.getSummary() : Resources.BUNDLE.getString(Resources.TEXT_NO_SUMMARY ))); 
			out.println("</A></TD></TR>");
		}

		if (timedEvents.length == 0) {
			for (int i = gridFirstHour; i <= gridLastHour; i++) {
				gridHourBegin.set(Calendar.HOUR_OF_DAY, i);
				out.print("<TR><TD COLSPAN=7 ALIGN=LEFT>");
				outputGridTimeLink(out, gridHourBegin, 60);
				out.print("</TD><TR>");
			}
		}
		else {
			Calendar firstEvtStart = timedEvents[0].getEvtStart();
			if (firstEvtStart.before(gridHourBegin)) {
				gridHourBegin.set(Calendar.HOUR_OF_DAY, firstEvtStart.get(Calendar.HOUR_OF_DAY));
			}				
		}	
	
		for (int i = 0; i < timedEvents.length; i++) {
			event = timedEvents[i];
			Calendar evtStart = event.getEvtStart(), evtEnd = event.getEvtEnd();
			java.util.Date evtStartDate = evtStart.getTime(), evtEndDate = evtEnd.getTime();
			int evtStartDay = evtStart.get(Calendar.DAY_OF_YEAR),
				evtEndDay = evtEnd.get(Calendar.DAY_OF_YEAR);
			boolean conflict = dayInfo.isConflictingTimedEvent(event);

			iconName = CalendarAppView.getIconNameForCategory(event.getCategories());

			while (!evtStart.before(gridHourBegin)) {
				out.print("<TR><TD COLSPAN=7 ALIGN=LEFT>");
				outputGridTimeLink(out, gridHourBegin, 60);					
				out.println("</TD><TR>");
				gridHourBegin.add(Calendar.HOUR_OF_DAY, 1);
				gridHourEnd.add(Calendar.HOUR_OF_DAY, 1);
			}
	
			out.print("<TR><TD>");
			out.print(dfTime.format(evtStartDate));
			out.print(((viewDayOfYear != evtStartDay) ? "*" : ""));
			out.print("</TD><TD>-</TD><TD>");
			out.print( dfTime.format(evtEndDate));
			out.print(((viewDayOfYear != evtEndDay) ? "*" : ""));
			out.print("</TD><TD><IMG BORDER=0 SRC=\"/PIMImages/");
			out.print(iconName);
			out.print("\"></TD><TD>");
			out.print((conflict ? "<IMG BORDER=0 SRC=\"/PIMImages/event_conflict.gif\">" : "&nbsp;"));
			out.print("</TD><TD><A HREF=\"");
			out.print(UpdateEventController.buildUrl(event));
			out.print("\" TARGET=\"_top\">");
			CalendarAppView.outputEncodedDataValue(out, (((event.getSummary() != null) && (!event.getSummary().equals(""))) ? event.getSummary() : Resources.BUNDLE.getString(Resources.TEXT_NO_SUMMARY )));
			out.println("</A></TD></TR>");
			if (i == timedEvents.length -1) {
				for (int j = evtStart.get(Calendar.HOUR_OF_DAY) + 1; j <= gridLastHour; j++) {
					gridHourBegin.set(Calendar.HOUR_OF_DAY, j);
					out.print("<TR><TD COLSPAN=7 ALIGN=LEFT>");
					outputGridTimeLink(out, gridHourBegin, 60);	
					out.println("</TD><TR>");
				}
			}
		}
		out.println("</TABLE>");
	}
	/**
	 * Method outputViewContentWithoutTimeGrid.
	 * @param out
	 * @throws IOException
	 */
	protected void outputViewContentWithoutTimeGrid(ServletOutputStream out)
		throws java.io.IOException {
		Event[] allDayEvents = dayInfo.getAllDayEvents();
		Event[] timedEvents = dayInfo.getChronologicalTimedEvents();
		int viewDayOfYear = currentDate.get(Calendar.DAY_OF_YEAR);
		DateFormat dfTime = DateFormat.getTimeInstance(DateFormat.SHORT);
		Event event;
		String iconName = null;

		out.println("<TABLE BORDER=0>");
		for (int i = 0; i < allDayEvents.length; i++) {
			event = allDayEvents[i];
			iconName = CalendarAppView.getIconNameForCategory(event.getCategories());
			out.print("<TR><TD COLSPAN=3>");
			out.print(((i == 0) ? Resources.getNlsString(Resources.VAL_DUR_ALL_DAY) : ""));
			out.print("</TD><TD><IMG BORDER=0 SRC=\"/PIMImages/");
			out.print( iconName);
			out.print("\"></TD><TD>&nbsp;</TD><TD><A HREF=\"");
			out.print(UpdateEventController.buildUrl(event));
			out.print("\" TARGET=\"_top\">");
			CalendarAppView.outputEncodedDataValue(out, (((event.getSummary() != null) && (!event.getSummary().equals(""))) ? event.getSummary() : Resources.BUNDLE.getString(Resources.TEXT_NO_SUMMARY )));
			out.println("</A></TD></TR>");
		}
		for (int i = 0; i < timedEvents.length; i++) {
			event = timedEvents[i];
			Calendar evtStart = event.getEvtStart(), evtEnd = event.getEvtEnd();
			java.util.Date evtStartDate = evtStart.getTime(), evtEndDate = evtEnd.getTime();
			int evtStartDay = evtStart.get(Calendar.DAY_OF_YEAR),
				evtEndDay = evtEnd.get(Calendar.DAY_OF_YEAR);
			boolean conflict = dayInfo.isConflictingTimedEvent(event);

			iconName = CalendarAppView.getIconNameForCategory(event.getCategories());

			out.print("<TR><TD>");
			out.print(dfTime.format(evtStartDate));
			out.print(((viewDayOfYear != evtStartDay) ? "*" : ""));
			out.print("</TD><TD>-</TD><TD>");
			out.print(dfTime.format(evtEndDate));
			out.print(((viewDayOfYear != evtEndDay) ? "*" : ""));
			out.print("</TD><TD><IMG BORDER=0 SRC=\"/PIMImages/");
			out.print(iconName);
			out.print("\"></TD><TD>");
			out.print((conflict ? "<IMG BORDER=0 SRC=\"/PIMImages/event_conflict.gif\">" : "&nbsp;"));
			out.print("</TD><TD><A HREF=\"");
			out.print(UpdateEventController.buildUrl(event));
			out.print("\" TARGET=\"_top\">");
			CalendarAppView.outputEncodedDataValue(out, (((event.getSummary() != null) && (!event.getSummary().equals(""))) ? event.getSummary() : Resources.BUNDLE.getString(Resources.TEXT_NO_SUMMARY ))); 
			out.println("</A></TD></TR>");
		}
		out.println("</TABLE>");
	}
	/**
	 * @see com.ibm.pvc.example.calendar.view.CalendarAppView#outputViewHeading(ServletOutputStream)
	 */
	protected void outputViewHeading(ServletOutputStream out)
		throws java.io.IOException {
		Settings settings = SettingsDAO.getAppSettings();

		Calendar cal = (Calendar) currentDate.clone();

		cal.add(Calendar.DATE, -1);

		out.println(
			"<TABLE BGCOLOR="
				+ settings.getTitlesBgColor()
				+ " BORDER=0 CELLPADDING=0 CELLSPACING=0 WIDTH=100%><TR>");
		out.println("<TD ALIGN=LEFT VALIGN=CENTER>");
		out.print(
			"<A HREF=\"" + DayInfoController.buildUrl(cal) + "\" target=\"_top\">");
		out.print(
			"<IMG SRC=\"/PIMImages/Title-bar_arrow-left.gif\" ALT=\"" + Resources.BUNDLE.getString(Resources.ACTION_P_DAY) + "\"></A></TD>");

		cal.add(Calendar.DATE, +1);

		out.println("<TD ALIGN=CENTER VALIGN=CENTER WIDTH=*>");
		out.println(
			"<FONT SIZE=+1 COLOR="
				+ settings.getTitlesFgColor()
				+ ">"
				+ getTitle()
				+ "</FONT></TD>");

		cal.add(Calendar.DATE, +1);

		out.println("<TD ALIGN=RIGHT VALIGN=CENTER>");
		out.print(
			"<A HREF=\"" + DayInfoController.buildUrl(cal) + "\" target=\"_top\">");
		out.print(
			"<IMG SRC=\"/PIMImages/Title-bar_arrow-right.gif\" ALT=\"" + Resources.BUNDLE.getString(Resources.ACTION_N_DAY) + "\"></A></TD></TR></TABLE>");
	}
	/**
	 * @see com.ibm.pvc.example.calendar.view.CalendarAppView#outputViewMenu(ServletOutputStream)
	 */
	protected void outputViewMenu(ServletOutputStream out)
		throws java.io.IOException {
		outputViewMainMenu(out, this.currentDate);
	}
	/**
	 * @see com.ibm.pvc.example.calendar.view.CalendarAppView#getHelpFileName()
	 */
	public String getHelpFileName() throws java.io.IOException {
		return (CalendarViewConstants.HELP_IDH_CALENDAR);
	}
}