/* .COPYRIGHT:                                                                */
/*    Licensed Material - Program-Property of IBM                             */
/*    (C) Copyright IBM Corp. 2002 - All Rights Reserved                      */
/*                                                                            */
/* .DISCLAIMER:                                                               */
/*   The following [enclosed] code is sample code created by IBM              */
/*   Corporation.  This sample code is provided to you solely for use in      */
/*   connection with your internal evaluation of the Service Management       */
/*   Framework(TM) Toolkit (Program) during the term of Early Release license */
/*   for the Program, and for no other purpose.  The code is provided 'AS IS',*/
/*   without warranty of any kind.  IBM shall not be liable for any damages   */
/*   arising out of your use of the sample code, even if they have been       */
/*   advised of the possibility of such damages.                              */
package com.ibm.pvc.example.calendar.view;

import java.sql.SQLException;

import javax.servlet.ServletOutputStream;

import com.ibm.pvc.example.command.CommandSQLException;

/**
 * This is the ExceptionView class.
 * 
 * This class handles the rendering of the 1/4 VGA View of Exceptions that are
 * propogated from a Controller class to the UI. 
 * 
 * Instances of this class are contructed with the exception to render passed as a parameter..
 */
public class ExceptionView extends CalendarAppView {
	private Exception exception;

	/**
	 * Method ExceptionView.
	 * @param exception
	 */
	public ExceptionView(Exception exception) {
		super();
		this.exception = exception;
	}
	/**
	 * @see com.ibm.pvc.example.calendar.view.CalendarAppView#getTitle()
	 */
	protected String getTitle() {
		return Resources.getNlsString(Resources.HEAD_ERROR);
	}
	/**
	 * @see com.ibm.pvc.example.calendar.view.CalendarAppView#outputViewContent(ServletOutputStream)
	 */
	protected void outputViewContent(ServletOutputStream out)
		throws java.io.IOException {
		out.println("<BR>" + exception.toString());

		out.println("<BR>" + exception.getMessage());

		if (exception instanceof CommandSQLException) {
			SQLException
				sqlException = ((CommandSQLException)exception).getSqlException(); 
			out.println(
				"<BR>SQLException.getErrorCode(): " + sqlException.getErrorCode());
			out.println(
				"<BR>SQLException.getSQLState(): " + sqlException.getSQLState());
		}
	}
	/**
	 * Method outputViewHeader.
	 * @param out
	 * @throws IOException
	 */
	protected void outputViewHeader(ServletOutputStream out)
		throws java.io.IOException {
		out.println(exception.toString());
	}
}