/* .COPYRIGHT:                                                                */
/*    Licensed Material - Program-Property of IBM                             */
/*    (C) Copyright IBM Corp. 2002 - All Rights Reserved                      */
/*                                                                            */
/* .DISCLAIMER:                                                               */
/*   The following [enclosed] code is sample code created by IBM              */
/*   Corporation.  This sample code is provided to you solely for use in      */
/*   connection with your internal evaluation of the Service Management       */
/*   Framework(TM) Toolkit (Program) during the term of Early Release license */
/*   for the Program, and for no other purpose.  The code is provided 'AS IS',*/
/*   without warranty of any kind.  IBM shall not be liable for any damages   */
/*   arising out of your use of the sample code, even if they have been       */
/*   advised of the possibility of such damages.                              */
package com.ibm.pvc.example.calendar.view;

import java.text.DateFormatSymbols;

import javax.servlet.ServletOutputStream;

import com.ibm.pvc.example.calendar.CalendarConstants;
import com.ibm.pvc.example.calendar.controller.DayInfoController;
import com.ibm.pvc.example.calendar.controller.MonthInfoController;
import com.ibm.pvc.example.calendar.controller.SettingsController;
import com.ibm.pvc.example.calendar.controller.WeekInfoController;
import com.ibm.pvc.example.calendar.model.Settings;

/**
 * This is the SettingsView class.
 * 
 * This class handles the rendering of the 1/4 VGA Settings View in the Calendar Servlet.
 * 
 * Instances of this class are contructed with the Settings object to used in building the
 * form to be rendered passed as a parameter.
 * 
 */public class SettingsView extends CalendarAppView {
	private Settings settings;
	/**
	 * SettingsView constructor comment.
	 */
	public SettingsView(Settings settings) {
		super();
		this.settings = settings;
	}
	/**
	 * @see com.ibm.pvc.example.calendar.view.CalendarAppView#getTitle()
	 */
	protected String getTitle() {
		return Resources.BUNDLE.getString(Resources.HEAD_SETTINGS);
	}

	/**
	 * @see com.ibm.pvc.example.calendar.view.CalendarAppView#outputViewContent(ServletOutputStream)
	 */
	public void outputViewContent(ServletOutputStream out)
		throws java.io.IOException {
		int firstHour = settings.getDailyTimeGridFirstHour();
		boolean isFirstHourAm = true;
		if (firstHour >= 12) {
			firstHour -= 12;
			isFirstHourAm = false;
		}
		int lastHour = settings.getDailyTimeGridLastHour();
		boolean isLastHourAm = true;
		if (lastHour >= 12) {
			lastHour -= 12;
			isLastHourAm = false;
		}

		DateFormatSymbols
			dfs = new DateFormatSymbols();
		String[] weekdays = dfs.getWeekdays();
		String[] amPmStrings = dfs.getAmPmStrings();		

		String defaultView = settings.getDefaultAction();
		String bgColor = settings.getTitlesBgColor();
		String fgColor = settings.getTitlesFgColor();	

		out.println(
			"<FORM NAME=\"SettingsForm\" ACTION=\""
				+ SettingsController.buildUrl()
				+ "\" METHOD=POST TARGET=\"_top\">");
		out.println("<TABLE><TR>");
		out.println(
			"<TD><INPUT TYPE=\"checkbox\" NAME=\"DailyGridDisplay\" VALUE=\"Yes\""
				+ ((settings.isShowDailyTimeGrid()) ? " CHECKED " : "")
				+ "></TD><TD>" + Resources.BUNDLE.getString(Resources.FLD_SHOW_GRID) +  "<BR>");
		out.println("</TD>");
		out.println("</TR><TR>");
		out.println("<TD></TD><TD>");

		out.println("<TABLE BORDER=0><TR>");
		out.println("<TD>" + Resources.BUNDLE.getString(Resources.FLD_START_TIME) + "</TD><TD>");
		out.println("<SELECT NAME=\"FirstHour\">");
		for (int i = 1; i <= 12; i++) {
			out.println(
				"<OPTION VALUE=\""
					+ ((i != 12) ? i : 0)
					+ "\" "
					+ ((((i != 12) ? i : 0) == firstHour) ? "SELECTED" : "")
					+ ">"
					+ i
					+ " </OPTION>");
		}
		out.println("</SELECT>");
		out.println("<SELECT NAME=\"FirstAmPm\">");
		out.println(
			"<OPTION VALUE=\"AM\"" + ((isFirstHourAm) ? "SELECTED" : "") + ">" + amPmStrings[0] + "</OPTION>");
		out.println(
			"<OPTION VALUE=\"PM\"" + ((!isFirstHourAm) ? "SELECTED" : "") + ">" + amPmStrings[1] + "</OPTION>");
		out.println("</SELECT>");
		out.println("</TD></TR><TR>");
		out.println("<TD>" + Resources.BUNDLE.getString(Resources.FLD_END_TIME) + "</TD><TD>");
		out.println("<SELECT NAME=\"LastHour\">");
		for (int i = 1; i <= 12; i++) {
			out.println(
				"<OPTION VALUE=\""
					+ ((i != 12) ? i : 0)
					+ "\" "
					+ ((((i != 12) ? i : 0) == lastHour) ? "SELECTED" : "")
					+ ">"
					+ i
					+ " </OPTION>");
		}
		out.println("</SELECT>");
		out.println("<SELECT NAME=\"LastAmPm\">");
		out.println(
			"<OPTION VALUE=\"AM\"" + ((isLastHourAm) ? "SELECTED" : "") + ">" + amPmStrings[0] + "</OPTION>");
		out.println(
			"<OPTION VALUE=\"PM\"" + ((!isLastHourAm) ? "SELECTED" : "") + ">" + amPmStrings[1] + "</OPTION>");
		out.println("</SELECT>");
		out.println("</TD></TR></TABLE>");
		out.println("</TD>");
		out.println("</TR></TABLE>");
 		out.println("<BR><BR>");
		out.print(Resources.BUNDLE.getString(Resources.FLD_DEFAULT_VIEW));
		out.println("<SELECT NAME=\"DefaultView\">");
		out.println(
			"<OPTION VALUE=\""
				+ DayInfoController.ACTION
				+ "\""
				+ ((defaultView.equals(DayInfoController.ACTION)) ? "SELECTED" : "")
				+ ">Daily</OPTION>");
		out.println(
			"<OPTION VALUE=\""
				+ WeekInfoController.ACTION
				+ "\""
				+ ((defaultView.equals(WeekInfoController.ACTION)) ? "SELECTED" : "")
				+ ">Weekly</OPTION>");
		out.println(
			"<OPTION VALUE=\""
				+ MonthInfoController.ACTION
				+ "\""
				+ ((defaultView.equals(MonthInfoController.ACTION)) ? "SELECTED" : "")
				+ ">Monthly</OPTION>");
		out.println(
			"<OPTION VALUE=\""
				+ SettingsController.ACTION
				+ "\""
				+ ((defaultView.equals(SettingsController.ACTION)) ? "SELECTED" : "")
				+ ">Settings</OPTION>");

		out.println("</SELECT>");
		out.println("<BR><BR>");
		String[] colorArray =
			{
				CalendarConstants.HTML_COLOR_AQUA,
				CalendarConstants.HTML_COLOR_BLACK,
				CalendarConstants.HTML_COLOR_BLUE,
				CalendarConstants.HTML_COLOR_FUCHSIA,
				CalendarConstants.HTML_COLOR_GREEN,
				CalendarConstants.HTML_COLOR_GRAY,
				CalendarConstants.HTML_COLOR_LIME,
				CalendarConstants.HTML_COLOR_MAROON,
				CalendarConstants.HTML_COLOR_NAVY,
				CalendarConstants.HTML_COLOR_OLIVE,
				CalendarConstants.HTML_COLOR_PURPLE,
				CalendarConstants.HTML_COLOR_RED,
				CalendarConstants.HTML_COLOR_SILVER,
				CalendarConstants.HTML_COLOR_TEAL,
				CalendarConstants.HTML_COLOR_WHITE,
				CalendarConstants.HTML_COLOR_YELLOW };
		out.print(Resources.BUNDLE.getString(Resources.FLD_BGCOLOR));
		out.println("<SELECT NAME=\"BGColor\">");
		for (int i = 1; i < colorArray.length; i++) {
			out.println(
				"<OPTION VALUE=\""
					+ colorArray[i]
					+ "\" "
					+ ((colorArray[i].equals(bgColor)) ? "SELECTED" : "")
					+ ">"
					+ colorArray[i]
					+ " </OPTION>");
		};
		out.println("</SELECT>");
		out.println("<BR><BR>");
		out.print(Resources.BUNDLE.getString(Resources.FLD_FGCOLOR));
		out.println("<SELECT NAME=\"FGColor\">");
		for (int i = 1; i < colorArray.length; i++) {
			out.println(
				"<OPTION VALUE=\""
					+ colorArray[i]
					+ "\" "
					+ ((colorArray[i].equals(fgColor)) ? "SELECTED" : "")
					+ ">"
					+ colorArray[i]
					+ " </OPTION>");
		}
		out.println("</SELECT>");
		out.println("<BR><BR>");
 		out.println("<INPUT TYPE=\"checkbox\" NAME=\"OverflowSupported\" VALUE=\"Yes\""
 				+ ((settings.isOverflowSupported()) ? " CHECKED " : "")
  				+ ">" + Resources.BUNDLE.getString(Resources.FLD_OVERFLOW_SUP) + "<BR><BR>");
		out.println("<INPUT TYPE=SUBMIT VALUE=\"" + Resources.BUNDLE.getString(Resources.ACTION_OK) + "\" NAME=\"SUBMIT\">");
		out.println("</FORM>");
	}
	/**
	 * @see com.ibm.pvc.example.calendar.view.CalendarAppView#getHelpFileName()
	 */
	public String getHelpFileName() throws java.io.IOException {
		return (CalendarViewConstants.HELP_IDH_SETTINGS);
	}	
}