/* .COPYRIGHT:                                                                */
/*    Licensed Material - Program-Property of IBM                             */
/*    (C) Copyright IBM Corp. 2002 - All Rights Reserved                      */
/*                                                                            */
/* .DISCLAIMER:                                                               */
/*   The following [enclosed] code is sample code created by IBM              */
/*   Corporation.  This sample code is provided to you solely for use in      */
/*   connection with your internal evaluation of the Service Management       */
/*   Framework(TM) Toolkit (Program) during the term of Early Release license */
/*   for the Program, and for no other purpose.  The code is provided 'AS IS',*/
/*   without warranty of any kind.  IBM shall not be liable for any damages   */
/*   arising out of your use of the sample code, even if they have been       */
/*   advised of the possibility of such damages.                              */
package com.ibm.pvc.example.calendar.view;

import java.text.DateFormat;
import java.util.Calendar;

import javax.servlet.ServletOutputStream;

import com.ibm.pvc.example.calendar.CalendarServletHelper;
import com.ibm.pvc.example.calendar.controller.DayInfoController;
import com.ibm.pvc.example.calendar.controller.UpdateEventController;
import com.ibm.pvc.example.calendar.controller.WeekInfoController;
import com.ibm.pvc.example.calendar.model.DayInfo;
import com.ibm.pvc.example.calendar.model.Event;
import com.ibm.pvc.example.calendar.model.Settings;
import com.ibm.pvc.example.calendar.model.SettingsDAO;

/**
 * This is the WeekInfoView class.
 * 
 * This class handles the rendering of the 1/4 VGA Weekly View in the Calendar Servlet.
 * 
 * Instances of this class are contructed with both a day in the week (used to determine which 
 * week to display) and all the information to be displayed for the days in that week passed 
 * in as parameters.
 */
public class WeekInfoView extends CalendarAppView {
	private Calendar currentDate;
	private DayInfo[] dayInfos;
	/**
	 * Method WeekInfoView.
	 * @param currentDate
	 * @param dayInfos
	 */
	public WeekInfoView(Calendar currentDate, DayInfo[] dayInfos) {
		super();
		this.currentDate = currentDate;
		this.dayInfos = dayInfos;
	}
	/**
	 * @see com.ibm.pvc.example.calendar.view.CalendarAppView#getTitle()
	 */
	protected String getTitle() {
		Calendar cal = (Calendar) currentDate.clone();

		cal.set(Calendar.DAY_OF_WEEK, cal.getMinimum(Calendar.DAY_OF_WEEK));

		return Resources.getNlsString(
			Resources.HEAD_WEEK_VIEW,
			(new Object[] { DateFormat
				.getDateInstance(DateFormat.MEDIUM)
				.format(cal.getTime())}));
	}
	/**
	 * @see com.ibm.pvc.example.calendar.view.CalendarAppView#outputViewContent(ServletOutputStream)
	 */
	protected void outputViewContent(ServletOutputStream out)
		throws java.io.IOException {
		Settings settings = SettingsDAO.getAppSettings();

		Calendar cal = (Calendar) currentDate.clone();

		cal.set(Calendar.DAY_OF_WEEK, cal.getMinimum(Calendar.DAY_OF_WEEK));

		out.println(
			"<TABLE BORDER=0 CELLPADDING=0 CELLSPACING=0 ALIGN=CENTER WIDTH=100%><TR><TD>&nbsp</TD></TR><TR>");

		for (int j = 0; j < 7; j++) {

			out.print("<TR><TD COLSPAN=7>");
			out.print("<TABLE BGCOLOR=" + settings.getTitlesBgColor() + " BORDER=0 CELLPADDING=0 CELLSPACING=0 WIDTH=100%><TR>");
			out.print("<TD ALIGN=CENTER VALIGN=CENTER WIDTH=100%>");
			out.print("<FONT SIZE=+1 COLOR=" + settings.getTitlesFgColor() + ">");
			out.print(
				"<A HREF=\"" + DayInfoController.buildUrl(cal) + "\" target=\"_top\">");
			out.print(DateFormat.getDateInstance(DateFormat.FULL).format(cal.getTime()));
			out.print("</A>");
			out.print("</FONT></TD></TR></TABLE>");
			out.println("</TD></TR>");
			
			DayInfo dayInfo = CalendarServletHelper.getDayInfoForDay(dayInfos, cal);
			if (dayInfo != null) {
				outputTableRowsForDay(out, cal, dayInfo);
			}
			else {
				out.println("<TR><TD>&nbsp</TD></TR>");
			}
			cal.add(Calendar.DATE, +1);
		}
		out.println("</TABLE>");
	}
	/**
	 * Method outputTableRowsForDay.
	 * @param out
	 * @param contextDate
	 * @param dayInfo
	 * @throws IOException
	 */
	protected void outputTableRowsForDay(
		ServletOutputStream out,
		Calendar contextDate,
		DayInfo dayInfo)
		throws java.io.IOException {
		Event[] allDayEvents = dayInfo.getAllDayEvents();
		Event[] timedEvents = dayInfo.getChronologicalTimedEvents();
		int viewDayOfYear = contextDate.get(Calendar.DAY_OF_YEAR);
		DateFormat dfTime = DateFormat.getTimeInstance(DateFormat.SHORT);
		Event event;
		String iconName = null;

		for (int i = 0; i < allDayEvents.length; i++) {
			event = allDayEvents[i];
			iconName = CalendarAppView.getIconNameForCategory(event.getCategories());
			out.print("<TR><TD COLSPAN=3>");
			out.print(((i == 0) ? Resources.getNlsString(Resources.VAL_DUR_ALL_DAY) : ""));
			out.print("</TD><TD><IMG BORDER=0 SRC=\"/PIMImages/");
			out.print(iconName);
			out.print("\"></TD><TD>&nbsp;</TD><TD><A HREF=\"");
			out.print(UpdateEventController.buildUrl(event));
			out.print("\" TARGET=\"_top\">");
			CalendarAppView.outputEncodedDataValue(out, (((event.getSummary() != null) && (!event.getSummary().equals(""))) ? event.getSummary() : Resources.BUNDLE.getString(Resources.TEXT_NO_SUMMARY ))); 
			out.println("</A></TD></TR>");
		}
		for (int i = 0; i < timedEvents.length; i++) {
			event = timedEvents[i];
			Calendar evtStart = event.getEvtStart(), evtEnd = event.getEvtEnd();
			java.util.Date evtStartDate = evtStart.getTime(), evtEndDate = evtEnd.getTime();
			int evtStartDay = evtStart.get(Calendar.DAY_OF_YEAR),
				evtEndDay = evtEnd.get(Calendar.DAY_OF_YEAR);
			boolean conflict = dayInfo.isConflictingTimedEvent(event);

			iconName = CalendarAppView.getIconNameForCategory(event.getCategories());

			out.print("<TR><TD>");
			out.print(dfTime.format(evtStartDate));
			out.print(((viewDayOfYear != evtStartDay) ? "*" : ""));
			out.print("</TD><TD>-</TD><TD>");
			out.print(dfTime.format(evtEndDate));
			out.print(((viewDayOfYear != evtEndDay) ? "*" : ""));
			out.print("</TD><TD><IMG BORDER=0 SRC=\"/PIMImages/");
			out.print(iconName);
			out.print("\"></TD><TD>");
			out.print( (conflict ? "<IMG BORDER=0 SRC=\"/PIMImages/event_conflict.gif\">" : "&nbsp;"));
			out.print("</TD><TD><A HREF=\"");
			out.print( UpdateEventController.buildUrl(event));
			out.print("\" TARGET=\"_top\">");			
			CalendarAppView.outputEncodedDataValue(out, (((event.getSummary() != null) && (!event.getSummary().equals(""))) ? event.getSummary() : Resources.BUNDLE.getString(Resources.TEXT_NO_SUMMARY ))); 
			out.println("</A></TD></TR>");
		}
		
		out.println("<TR><TD>&nbsp</TD></TR>");	
	}
	/**
	 * @see com.ibm.pvc.example.calendar.view.CalendarAppView#outputViewHeading(ServletOutputStream)
	 */
	protected void outputViewHeading(ServletOutputStream out)
		throws java.io.IOException {
		Settings settings = SettingsDAO.getAppSettings();	
				
		Calendar cal = (Calendar) currentDate.clone();

		cal.add(Calendar.DATE, -7);
		out.println(
			"<TABLE BGCOLOR="
				+ settings.getTitlesBgColor()
				+ " BORDER=0 CELLPADDING=0 CELLSPACING=0 WIDTH=100%><TR>");
		out.println("<TD ALIGN=LEFT VALIGN=CENTER>");
		out.print(
			"<A HREF=\"" + WeekInfoController.buildUrl(cal) + "\" target=\"_top\">");
		out.print(
			"<IMG SRC=\"/PIMImages/Title-bar_arrow-left.gif\" ALT=\"" + Resources.BUNDLE.getString(Resources.ACTION_P_WEEK) + "\"></A></TD>");

		out.println("<TD ALIGN=CENTER VALIGN=CENTER WIDTH=*>");
		out.println(
			"<FONT SIZE=+1 COLOR="
				+ settings.getTitlesFgColor()
				+ ">"
				+ getTitle()
				+ "</FONT></TD>");

		cal.add(Calendar.DATE, +14);
		out.println("<TD ALIGN=RIGHT VALIGN=CENTER>");
		out.print(
			"<A HREF=\"" + WeekInfoController.buildUrl(cal) + "\" target=\"_top\">");
		out.print(
			"<IMG SRC=\"/PIMImages/Title-bar_arrow-right.gif\" ALT=\"" + Resources.BUNDLE.getString(Resources.ACTION_N_WEEK) + "\"></A>");
		out.print("</TD></TR></TABLE>");
	}
	/**
	 * @see com.ibm.pvc.example.calendar.view.CalendarAppView#outputViewMenu(ServletOutputStream)
	 */
	protected void outputViewMenu(ServletOutputStream out)
		throws java.io.IOException {
		outputViewMainMenu(out, this.currentDate);
	}
	/**
	 * @see com.ibm.pvc.example.calendar.view.CalendarAppView#getHelpFileName()
	 */
	public String getHelpFileName() throws java.io.IOException {
		return (CalendarViewConstants.HELP_IDH_WEEKLY);
	}	
}